@@ -1,10 +1,11 @@
-from .__main__ import nix_prefetch_github
 from .core import (
     CalculateSha256Sum,
     GetListRemote,
+    GithubRepository,
     TryPrefetch,
     is_sha1_hash,
     prefetch_github,
 )
 from .core.list_remote import ListRemote
 from .effect import detect_actual_hash_from_nix_output, dispatcher
+from .public import check_repository_is_dirty, nix_prefetch_github
