@@ -1,3 +1,4 @@
+from .directory import check_repository_is_dirty, prefetch_directory
 from .effects import (
     AbortWithErrorMessage,
     CalculateSha256Sum,
@@ -6,14 +7,17 @@ from .effects import (
     DetectRevision,
     GetCurrentDirectory,
     GetListRemote,
+    GetRevisionForLatestRelease,
     ShowWarning,
     TryPrefetch,
 )
+from .error import AbortWithError
 from .prefetch import (
-    GithubRepository,
-    github_repository_url,
+    PrefetchedRepository,
     is_sha1_hash,
     prefetch_github,
+    prefetch_latest_release,
+    repository_not_found_error_message,
     revision_not_found_errormessage,
 )
-from .prefetch_directory import prefetch_directory
+from .repository import GithubRepository
